@@ -55,6 +55,7 @@ class Main(Gtk.Application):
         action = Gio.SimpleAction.new('preferences', None)
         action.connect('activate', lambda *a: self.preferences())
         self.add_action(action)
+        self.set_accels_for_action('app.preferences', ['<Primary><Shift>p'])
 
         action = Gio.SimpleAction.new('menu-search', None)
         action.connect(
@@ -110,7 +111,7 @@ class Main(Gtk.Application):
         action = Gio.SimpleAction.new('shortcuts', None)
         action.connect('activate', lambda *a: self.shortcuts())
         self.add_action(action)
-        self.set_accels_for_action('app.shortcuts', ['<Primary>F1'])
+        self.set_accels_for_action('app.shortcuts', ['<Primary><Shift>F1'])
 
         action = Gio.SimpleAction.new('about', None)
         action.connect('activate', lambda *a: self.about())
@@ -135,39 +136,41 @@ class Main(Gtk.Application):
         self.set_accels_for_action('app.gh_cli', ['<Primary><Shift>Z'])
 
 
-        menu = Gio.Menu.new()
-        menu.append(_("Preferences..."), 'app.preferences')
-
-        section = Gio.Menu.new()
+        # Main Menu
+        main_menu = Gio.Menu.new()
+        file_menu = Gio.Menu.new()
+        settings_menu = Gio.Menu.new()
+        help_menu = Gio.Menu.new()
         toolbar = Gio.Menu.new()
-        section.append_submenu(_("Toolbar"), toolbar)
+        main_menu.append_submenu(_("File"), file_menu)
+        main_menu.append_submenu(_("Settings"), settings_menu)
+        main_menu.append_submenu(_("Help"), help_menu)
+
+        settings_menu.append(_("Preferences..."), 'app.preferences')
+
+        settings_menu.append_submenu(_("Toolbar"), toolbar)
         toolbar.append(_("Default"), 'app.toolbar::default')
         toolbar.append(_("Text and Icons"), 'app.toolbar::both')
         toolbar.append(_("Text"), 'app.toolbar::text')
         toolbar.append(_("Icons"), 'app.toolbar::icons')
 
         form = Gio.Menu.new()
-        section.append_submenu(_("Form"), form)
+        settings_menu.append_submenu(_("Form"), form)
         form.append(_("Save Width/Height"), 'app.save-width-height')
         form.append(_("Save Tree State"), 'app.save-tree-state')
-        form.append(_("Fast Tabbing"), 'app.fast-tabbing')
         form.append(_("Spell Checking"), 'app.spell-checking')
 
-        section.append(_("Search Limit..."), 'app.search-limit')
-        section.append(_("Email..."), 'app.email')
+        settings_menu.append(_("Search Limit..."), 'app.search-limit')
+        settings_menu.append(_("Email..."), 'app.email')
 
-        menu.append_section(_("Options"), section)
 
-        section = Gio.Menu.new()
-        section.append(_("Keyboard Shortcuts..."), 'app.shortcuts')
-        section.append(_("About..."), 'app.about')
-        menu.append_section(_("Help"), section)
+        help_menu.append(_("Keyboard Shortcuts..."), 'app.shortcuts')
+        help_menu.append(_("About..."), 'app.about')
 
-        section = Gio.Menu.new()
-        section.append(_("Quit"), 'app.quit')
-        menu.append_section(None, section)
+        file_menu.append(_("Quit"), 'app.quit')
+
+        self.set_menubar(main_menu)
 
-        self.set_app_menu(menu)
 
     def do_activate(self):
         if self.window:
@@ -176,37 +179,14 @@ class Main(Gtk.Application):
 
         self.window = Gtk.ApplicationWindow(application=self, title="GNU Health")
         self.window.set_default_size(960, 720)
-        self.window.maximize()
         self.window.set_position(Gtk.WindowPosition.CENTER)
         self.window.set_resizable(True)
         self.window.set_icon(GNUHEALTH_ICON)
         self.window.connect("destroy", self.on_quit)
         self.window.connect("delete_event", self.on_quit)
 
-        self.header = Gtk.HeaderBar.new()
-        self.header.set_show_close_button(True)
-        self.window.set_titlebar(self.header)
         self.set_title()
 
-        menu = Gtk.Button.new()
-        menu .set_relief(Gtk.ReliefStyle.NONE)
-        menu.set_image(
-            common.IconFactory.get_image('tryton-menu', Gtk.IconSize.BUTTON))
-        menu.connect('clicked', self.menu_toggle)
-        self.header.pack_start(menu)
-
-        favorite = Gtk.MenuButton.new()
-        favorite.set_relief(Gtk.ReliefStyle.NONE)
-        favorite.set_image(common.IconFactory.get_image(
-                'tryton-bookmarks', Gtk.IconSize.BUTTON))
-        self.menu_favorite = Gtk.Menu.new()
-        favorite.set_popup(self.menu_favorite)
-        favorite.connect('clicked', self.favorite_set)
-        self.header.pack_start(favorite)
-
-        self.set_global_search()
-        self.header.pack_start(self.global_search_entry)
-
         self.accel_group = Gtk.AccelGroup()
         self.window.add_accel_group(self.accel_group)
 
@@ -284,10 +264,13 @@ class Main(Gtk.Application):
         # Register plugins
         tryton.plugins.register()
 
+        # Initialize GNU Health environment
         # GNUHEALTH CLI
         self.cli = self.statusbar = self.footer_contents = self.footer = None
         self.cli_position = CONFIG['client.cli_position']
 
+        self.init_gnuhealth_env()
+
 
         self.set_title()  # Adds username/profile while password is asked
         try:
@@ -304,9 +287,6 @@ class Main(Gtk.Application):
         msg = "Connected to GNU Health Server"
         self.activity_log_entry(msg, 'info')
 
-        # Set the footer
-        self.init_gnuhealth_env()
-
 
     def gnuhealth_cli(self):
         self.cli.grab_focus()
@@ -444,19 +424,8 @@ class Main(Gtk.Application):
         titles = [CONFIG['client.title']]
         if value:
             titles.append(value)
-        self.header.set_title(' - '.join(titles))
-        self.header.set_subtitle(login_info)
-        try:
-            style_context = self.header.get_style_context()
-        except AttributeError:
-            pass
-        else:
-            for name in style_context.list_classes():
-                if name.startswith('profile-'):
-                    style_context.remove_class(name)
-            if CONFIG['login.profile']:
-                style_context.add_class(
-                    'profile-%s' % CONFIG['login.profile'])
+        titles.append(login_info)
+        self.window.set_title(' - '.join(titles))
 
     def favorite_set(self, *args):
         if self.menu_favorite.get_children():
@@ -566,7 +535,7 @@ class Main(Gtk.Application):
                 self.favorite_unset()
             CONFIG['client.lang'] = prefs['language']
         # Set placeholder after language is set to get correct translation
-        self.global_search_entry.set_placeholder_text(_("Action"))
+        self.global_search_entry.set_placeholder_text(_("Global Search"))
         CONFIG.save()
 
     def preferences(self):
@@ -882,6 +851,7 @@ class Main(Gtk.Application):
         hbox.show_all()
         label_menu = Gtk.Label(
             label=page.name, halign=Gtk.Align.START)
+        page.widget.props.margin = 3
         self.notebook.insert_page_menu(page.widget, hbox, label_menu, page_id)
         self.notebook.set_tab_reorderable(page.widget, True)
         self.notebook.set_current_page(page_id)
@@ -1128,32 +1098,63 @@ class Main(Gtk.Application):
         self.ghheader = Gtk.HBox()
         self.ghheader.set_size_request(200,-1)
 
-
         # Main footer
         self.ghfooter = Gtk.HBox()
 
-        # Create initally a 1x3 table for the footer, leaving the
-        # middle column empty
-        self.ghfooter_contents = Gtk.Table(1,3,True)
+        # Create initally a grid for the footer
+        self.ghfooter_contents = Gtk.Grid()
 
-        # Create initally a 1x3 table for the header
-        self.ghheader_contents = Gtk.Table(1,3,True)
+        # Create initally a grid for the header
+        self.ghheader_contents = Gtk.Grid()
 
         # Set GNU Health Footer
         self.set_ghfooter()
 
         cli_position = self.cli_position
 
+        # Include the side menu toggle
+        side_menu = Gtk.Button.new()
+        side_menu.set_image(
+            common.IconFactory.get_image('tryton-menu', Gtk.IconSize.BUTTON))
+        side_menu.connect('clicked', self.menu_toggle)
+
+        # End of side-menu toggle
+
+        # Favorite entries
+        favorite = Gtk.MenuButton.new()
+        favorite.set_relief(Gtk.ReliefStyle.NONE)
+        favorite.set_image(common.IconFactory.get_image(
+                'tryton-bookmarks', Gtk.IconSize.BUTTON))
+        self.menu_favorite = Gtk.Menu.new()
+        favorite.set_popup(self.menu_favorite)
+        favorite.connect('clicked', self.favorite_set)
+
+        self.set_global_search()
+
+
+
         #Default CLI position at top
         if (not cli_position or cli_position == 'top'):
-            self.ghheader_contents.attach(self.cli, 0, 1, 0, 1)
-            self.ghheader.pack_start(self.ghheader_contents,expand=True,
-                                fill=True, padding=0)
-            self.vbox.pack_start (self.ghheader,
-                                  expand=False, fill=False, padding=0)
+            self.ghheader_contents.add(self.cli)
+            self.ghheader_contents.attach_next_to(side_menu, self.cli,
+                                                  Gtk.PositionType.RIGHT, 1, 1)
 
-            self.vbox.reorder_child(self.ghheader, 1)
-            self.ghheader.show_all()
+        else:
+            self.ghheader_contents.add(side_menu)
+
+        self.ghheader_contents.attach_next_to(favorite, side_menu,
+                                              Gtk.PositionType.RIGHT, 1, 1)
+        self.ghheader_contents.attach_next_to(self.global_search_entry,
+                                        favorite, Gtk.PositionType.RIGHT, 1, 1)
+
+        self.ghheader.pack_start(self.ghheader_contents,expand=True,
+                            fill=True, padding=10)
+        self.vbox.pack_start (self.ghheader,
+                                expand=False, fill=False, padding=10)
+
+        self.vbox.reorder_child(self.ghheader, 1)
+
+        self.ghheader.show_all()
 
     # Add GNU Health Command Line and Status Bar in footer
     def set_ghfooter(self):
@@ -1162,11 +1163,15 @@ class Main(Gtk.Application):
         ghfooter_contents = self.ghfooter_contents
 
         if (self.cli_position == 'bottom'):
-            ghfooter_contents.attach(cli, 0, 1, 0, 1)
+            ghfooter_contents.add(cli)
+            ghfooter_contents.attach_next_to(statusbar,cli,
+                                             Gtk.PositionType.RIGHT, 1, 1)
 
-        ghfooter_contents.attach(statusbar,2, 3, 0, 1)
+        else:
+            ghfooter_contents.add(statusbar)
 
-        self.ghfooter.pack_start(ghfooter_contents, expand=True, fill=True, padding=0)
+        self.ghfooter.pack_start(ghfooter_contents, expand=True, fill=True,
+                                 padding=0)
 
         # Pack the footer table in main vbox
         self.vbox.pack_start (self.ghfooter, expand=False, fill=False, padding=0)
