@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import os
 import gettext
 from gi.repository import Gtk, GdkPixbuf
 
-from tryton.config import PIXMAPS_DIR, CONFIG, GNUHEALTH_ICON
+from tryton.config import PIXMAPS_DIR, CONFIG, GH_ABOUT
 from tryton.common import get_toplevel_window
 from tryton import __version__
 
@@ -692,7 +691,6 @@ Public License instead of this License.  But first, please read
 <http://www.gnu.org/philosophy/why-not-lgpl.html>.'''
 
 
-
 class About(object):
 
     def __init__(self):
@@ -704,7 +702,7 @@ class About(object):
         self.win.set_comments(POWERED_BY)
         self.win.set_license(LICENSE)
         self.win.set_website('http://www.gnuhealth.org/')
-        self.win.set_logo(GNUHEALTH_ICON)
+        self.win.set_logo(GH_ABOUT)
 
         self.win.run()
         parent.present()
