@@ -1,4 +1,4 @@
-# This file is part of the GNU Health GTK Client.  The COPYRIGHT file at the top level of
+# This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import gettext
 
@@ -13,7 +13,8 @@ def translate_view(datas):
     Window.create('ir.translation',
         res_id=False,
         domain=[('model', '=', model)],
-        mode=['tree', 'form'])
+        mode=['tree', 'form'],
+        name=_('Translate view'))
 
 
 def get_plugins(model):
